==> blessing-skin-server-v3.5.0.zip: config/options.php <==
<?php

return [
    'site_url'                  => '',
    'site_name'                 => 'Blessing Skin',
    'site_description'          => 'Open-source PHP Minecraft Skin Hosting Service',
    'user_can_register'         => 'true',
    'register_with_player_name' => 'true',
    'require_verification'      => 'false',
    'regs_per_ip'               => '3',
    'ip_get_method'             => '0',
    'api_type'                  => 'false',
    'announcement'              => 'Welcome to Blessing Skin {version}!',
    'color_scheme'              => 'skin-blue',
    'home_pic_url'              => './resources/assets/dist/images/bg.jpg',
    'custom_css'                => '',
    'custom_js'                 => '',
    'player_name_rule'          => 'official',
    'custom_player_name_regexp' => '',
    'player_name_length_min'    => '3',
    'player_name_length_max'    => '16',
    'comment_script'            => '',
    'allow_sending_statistics'  => 'true',
    'user_initial_score'        => '1000',
    'sign_gap_time'             => '24',
    'sign_score'                => '10,100',
    'score_per_storage'         => 'true',
    'private_score_per_storage' => '10',
    'return_score'              => 'true',
    'score_per_player'          => '100',
    'sign_after_zero'           => 'false',
    'version'                   => '',
    'copyright_text'            => '<strong>Copyright &copy; {year} <a href="{site_url}">{site_name}</a>.</strong> All rights reserved.',
    'auto_del_invalid_texture'  => 'false',
    'allow_downloading_texture' => 'true',
    'texture_name_regexp'       => '',
    'return_204_when_notfound'  => 'false',
    'cache_expire_time'         => '31536000',
    'max_upload_file_size'      => '1024',
    'force_ssl'                 => 'false',
    'auto_detect_asset_url'     => 'true',
    'plugins_enabled'           => '',
    'copyright_prefer'          => '0',
    'score_per_closet_item'     => '0',
    'favicon_url'               => 'dist/images/favicon.ico'
];

==> blessing-skin-server-6.0.2.zip: config/options.php <==
<?php

return [
    'site_url'                  => '',
    'site_name'                 => 'Blessing Skin',
    'site_description'          => 'Open-source PHP Minecraft Skin Hosting Service',
    'register_with_player_name' => 'true',
    'require_verification'      => 'false',
    'regs_per_ip'               => '3',
    'announcement'              => 'Welcome to Blessing Skin {version}!',
    'home_pic_url'              => './app/bg.webp',
    'custom_css'                => '',
    'custom_js'                 => '',
    'player_name_rule'          => 'official',
    'custom_player_name_regexp' => '',
    'player_name_length_min'    => '3',
    'player_name_length_max'    => '16',
    'user_initial_score'        => '1000',
    'sign_gap_time'             => '24',
    'sign_score'                => '10,100',
    'score_per_storage'         => 'true',
    'private_score_per_storage' => '10',
    'return_score'              => 'true',
    'score_per_player'          => '100',
    'sign_after_zero'           => 'false',
    'version'                   => '',
    'copyright_text'            => '<b>Copyright &copy; {year} <a href="{site_url}">{site_name}</a>.</b> All rights reserved.',
    'auto_del_invalid_texture'  => 'false',
    'allow_downloading_texture' => 'true',
    'texture_name_regexp'       => '',
    'cache_expire_time'         => '31536000',
    'max_upload_file_size'      => '1024',
    'force_ssl'                 => 'false',
    'auto_detect_asset_url'     => 'true',
    'plugins_enabled'           => '',
    'copyright_prefer'          => '0',
    'score_per_closet_item'     => '0',
    'favicon_url'               => 'app/favicon.ico',
    'score_award_per_texture'   => '0',
    'take_back_scores_after_deletion' => 'true',
    'score_award_per_like'      => '0',
    'meta_keywords'             => '',
    'meta_description'          => '',
    'meta_extras'               => '',
    'cdn_address'               => '',
    'recaptcha_sitekey'         => '',
    'recaptcha_secretkey'       => '',
    'recaptcha_invisible'       => 'false',
    'reporter_score_modification' => '0',
    'reporter_reward_score'     => '0',
    'content_policy'            => '',
    'transparent_navbar'        => 'false',
    'status_code_for_private'   => '403',
    'navbar_color'              => 'cyan',
    'sidebar_color'             => 'dark-maroon',
];
